
.. _glossary:

********
Glossary
********

.. glossary::

  AGG
      The Anti-Grain Geometry (`Agg <http://antigrain.com/>`_) rendering
      engine, capable of rendering high-quality images

  Cairo
      The `Cairo graphics <https://cairographics.org>`_ engine

  FreeType
      `FreeType <https://www.freetype.org/>`_ is a font rasterization
      library used by matplotlib which supports TrueType, Type 1, and
      OpenType fonts.

  GTK
      The GIMP Toolkit (`GTK <https://www.gtk.org/>`_) graphical user interface
      library

  PyGObject
      `PyGObject <http://www.pygtk.org/>`_ provides Python wrappers for the
      :term:`GTK` widgets library

  pyqt
      `pyqt <https://wiki.python.org/moin/PyQt>`_ provides python
      wrappers for the :term:`Qt` widgets library and is required by
      the matplotlib Qt5Agg and Qt4Agg backends.  Widely used on linux
      and windows; many linux distributions package this as
      'python-qt5' or 'python-qt4'.

  Qt
      `Qt <https://www.qt.io/>`__ is a cross-platform
      application framework for desktop and embedded development.

  Qt4
      `Qt4 <https://doc.qt.io/archives/qt-4.8/index.html>`__ is the previous,
      but most widely used, version of Qt cross-platform application
      framework for desktop and embedded development.

  Qt5
      `Qt5 <http://doc.qt.io/qt-5/index.html>`__ is the current
      version of Qt cross-platform application
      framework for desktop and embedded development.

  Tk
      `Tk <http://www.tcl.tk/>`_ is a graphical user interface for Tcl
      and many other dynamic languages. It can produce rich, native
      applications that run unchanged across Windows, Mac OS X, Linux
      and more.

  wxpython
      `wxpython <https://www.wxpython.org/>`_ provides python wrappers
      for the :term:`wxWidgets` library for use with the WX and WXAgg
      backends.  Widely used on linux, OS-X and windows, it is often
      packaged by linux distributions as 'python-wxgtk'

  wxWidgets
      `WX <http://www.wxwidgets.org/>`_ is cross-platform GUI and
      tools library for GTK, MS Windows, and MacOS.  It uses native
      widgets for each operating system, so applications will have the
      look-and-feel that users on that operating system expect.
